@@ -1,8 +1,10 @@
+import logging
 import socket
 import threading
 import time
 from typing import Optional
 
+from .error import VBANCMDError
 from .packet import HEADER_SIZE, SubscribeHeader, VbanRtPacket, VbanRtPacketHeader
 from .util import Socket
 
@@ -26,9 +28,9 @@ class Subscriber(threading.Thread):
                 self.packet.framecounter = count.to_bytes(4, "little")
                 time.sleep(10)
             except socket.gaierror as e:
-                print(f"Unable to resolve hostname {self._remote.ip}")
-                self._remote.socks[Socket.register].close()
-                raise e
+                err_msg = f"Unable to resolve hostname {self._remote.ip}"
+                print(err_msg)
+                raise VBANCMDError(err_msg)
 
 
 class Updater(threading.Thread):
@@ -38,6 +40,8 @@ class Updater(threading.Thread):
     notifies observers of event updates
     """
 
+    logger = logging.getLogger("worker.updater")
+
     def __init__(self, remote):
         super().__init__(name="updater", target=self.update, daemon=True)
         self._remote = remote
@@ -80,9 +84,9 @@ class Updater(threading.Thread):
                         _busLabelUTF8c60=data[932:1412],
                     )
         except TimeoutError as e:
-            print(f"Unable to establish connection with {self._remote.ip}")
-            [sock.close() for sock in self._remote.socks]
-            raise e
+            err_msg = f"Unable to establish connection with {self._remote.ip}"
+            print(err_msg)
+            raise VBANCMDError(err_msg)
 
     def _get_rt(self) -> VbanRtPacket:
         """Attempt to fetch data packet until a valid one found"""
@@ -97,7 +101,6 @@ class Updater(threading.Thread):
         return fget()
 
     def update(self):
-        print(f"Listening for {', '.join(self._remote.event.get())} events")
         (
             self._remote.cache["strip_level"],
             self._remote.cache["bus_level"],
